@@ -14,4 +14,4 @@ BACKEND = getattr(settings, 'UWSGI_EMAIL_BACKEND',
 @spool
 def send_mail(arguments):
     conn = get_connection(backend=BACKEND)
-    conn.send_messages([loads(arguments['email_message'])])
+    conn.send_messages([loads(arguments['body'])])
